@@ -4,13 +4,13 @@ from collections.abc import (
     AsyncIterator,
     Awaitable,
     Callable,
+    Collection,
     Generator,
     Iterable,
     Iterator,
-    Sequence,
 )
-from inspect import isfunction
-from types import GenericAlias, UnionType
+from inspect import isclass, isfunction
+from types import GenericAlias, NoneType, UnionType
 from typing import (
     Annotated,
     Any,
@@ -27,15 +27,13 @@ type TypeInfo[T] = (
     InputType[T]
     | Callable[..., T]
     | Callable[..., Awaitable[T]]
-    | Sequence[TypeInfo[T]]
+    | Collection[TypeInfo[T]]
 )
 
 
 def get_return_types(*args: TypeInfo[Any]) -> Iterator[InputType[Any]]:
     for arg in args:
-        if isinstance(arg, Iterable) and not (
-            isinstance(arg, type | str) or isinstance(get_origin(arg), type)
-        ):
+        if isinstance(arg, Collection) and not isclass(arg):
             inner_args = arg
 
         elif isfunction(arg) and (return_type := get_return_hint(arg)):
@@ -76,7 +74,7 @@ def standardize_types(
     with_origin: bool = False,
 ) -> Iterator[TypeDef[Any]]:
     for tp in types:
-        if tp is None:
+        if tp in (None, NoneType):
             continue
 
         origin = get_origin(tp)
